@@ -389,7 +389,7 @@ char *syck_strndup( char *, long );
 long syck_io_file_read( char *, SyckIoFile *, long, long );
 long syck_io_str_read( char *, SyckIoStr *, long, long );
 char *syck_base64enc( char *, long );
-char *syck_base64dec( char *, long );
+char *syck_base64dec( char *, long, long * );
 SyckEmitter *syck_new_emitter();
 SYMID syck_emitter_mark_node( SyckEmitter *, st_data_t );
 void syck_emitter_ignore_id( SyckEmitter *, SYMID );
